import React from 'react';
import { useNavigate } from 'react-router-dom';
import { queryTable } from '@/utils/request';
import { ProTable } from '@ant-design/pro-components';
import { Button, message, Popconfirm } from 'antd';
import { getMessageList } from '@/services/message';

const queryMessage = queryTable(getMessageList);

export default (props) => {
  const columns = [
    {
      title: 'id',
      dataIndex: 'id',
      search: false,
    },
    {
      title: '时间',
      dataIndex: 'createDate',
      valueType: 'date',
      search: false,
    },
    {
      title: '时间',
      dataIndex: 'createDate',
      valueType: 'dateRange',
      hideInTable: true,
      search: {
        transform: (value) => {
          return {
            startDate: value[0],
            endDate: value[1],
          };
        },
      },
    },
    {
      title: '内容',
      dataIndex: 'message',
    },
    {
      title: '状态',
      dataIndex: 'isReaded',
      search: false,
      valueEnum: {
        1: {
          text: '已读',
          status: 'Processing',
        },
        0: {
          text: '未读',
          status: 'Error',
        },
      },
    },
    {
      title: '操作',
      valueType: 'option',
      width: 200,
      render: (_, record) => [
        <Button
          key={2}
          style={{ padding: 0 }}
          type="link"
          onClick={() => {
            navigate(`/system/message/detail?id=${record.id}`);
          }}
        >
          详情
        </Button>,
      ],
    },
  ]

  return (
    <ProTable
      rowKey="id"
      request={queryMessage}
      columns={columns}
    />
  )
}
